# Tool Format Documentation

Research and specifications for AI coding agent configuration formats.

## Structure

- **agents/**: Agent configuration format specifications
  - Claude Code agent format
  - GitHub Copilot agent format

- **permissions/**: Permission configuration format specifications
  - Claude Code permissions format
  - GitHub Copilot permissions format

- **slash-commands/**: Slash command/prompt file format specifications
  - Claude Code slash commands format
  - GitHub Copilot prompt files format

## Purpose

These documents specify the structure and syntax of configuration files for various AI coding tools. Used as reference when implementing format adapters.

## For Application Documentation

See `docs/app/` for:
- User guide
- Developer documentation
- Architecture overview
- Testing guidelines
